==> haskell-lifted-async-0.9.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.9.0
id: lifted-async-0.9.0-K89Soa4Skyfq32op3oGfW
key: lifted-async-0.9.0-K89Soa4Skyfq32op3oGfW
license: BSD3
copyright: Copyright (C) 2012-2016 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <maoe@foldr.in>
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
author: Mitsutoshi Aoe
exposed: True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
abi: f97bb2b7b9fb8c0a5eadc22b64b731e2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-async-0.9.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-async-0.9.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/lifted-async-0.9.0
hs-libraries: HSlifted-async-0.9.0-K89Soa4Skyfq32op3oGfW
depends:
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM base-4.9.0.0
    constraints-0.8-KMghHLStkTCAXaiizrSlFk
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-async-0.9.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-async.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-async
version: 0.9.1
id: lifted-async-0.9.1-Bwox7wRPUwWFz74Tt37a1w
key: lifted-async-0.9.1-Bwox7wRPUwWFz74Tt37a1w
license: BSD3
copyright: Copyright (C) 2012-2017 Mitsutoshi Aoe
maintainer: Mitsutoshi Aoe <maoe@foldr.in>
homepage: https://github.com/maoe/lifted-async
synopsis: Run lifted IO operations asynchronously and wait for their results
description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
category: Concurrency
author: Mitsutoshi Aoe
exposed: True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe
abi: b92d6de056579d29d500345ca7c75419
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-async-0.9.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-async-0.9.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/lifted-async-0.9.1
hs-libraries: HSlifted-async-0.9.1-Bwox7wRPUwWFz74Tt37a1w
depends:
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM base-4.9.0.0
    constraints-0.8-6ebQqOtc5gnCoSa30ACr1e
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock
haddock-html: /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
